#define scheme_init_jmpup_buf (scheme_extension_table->scheme_init_jmpup_buf)
#define scheme_setjmpup_relative (scheme_extension_table->scheme_setjmpup_relative)
#define scheme_longjmpup (scheme_extension_table->scheme_longjmpup)
#define scheme_reset_jmpup_buf (scheme_extension_table->scheme_reset_jmpup_buf)
#ifdef USE_MZ_SETJMP
#define scheme_get_mz_setjmp (scheme_extension_table->scheme_get_mz_setjmp)
#define scheme_mz_setjmp (scheme_extension_table->scheme_mz_setjmp)
#define scheme_mz_longjmp (scheme_extension_table->scheme_mz_longjmp)
#endif
#define scheme_clear_escape (scheme_extension_table->scheme_clear_escape)
#define scheme_new_jmpupbuf_holder (scheme_extension_table->scheme_new_jmpupbuf_holder)
#define scheme_current_config (scheme_extension_table->scheme_current_config)
#define scheme_minimal_config (scheme_extension_table->scheme_minimal_config)
#define scheme_extend_config (scheme_extension_table->scheme_extend_config)
#define scheme_install_config (scheme_extension_table->scheme_install_config)
#define scheme_get_param (scheme_extension_table->scheme_get_param)
#define scheme_set_param (scheme_extension_table->scheme_set_param)
#define scheme_get_thread_param (scheme_extension_table->scheme_get_thread_param)
#define scheme_set_thread_param (scheme_extension_table->scheme_set_thread_param)
#define scheme_get_env (scheme_extension_table->scheme_get_env)
#define scheme_empty_cell_table (scheme_extension_table->scheme_empty_cell_table)
#define scheme_inherit_cells (scheme_extension_table->scheme_inherit_cells)
#define scheme_current_break_cell (scheme_extension_table->scheme_current_break_cell)
#ifndef USE_THREAD_LOCAL
# ifndef LINK_EXTENSIONS_BY_TABLE
#define scheme_current_thread (scheme_extension_table->scheme_current_thread)
#define scheme_fuel_counter (scheme_extension_table->scheme_fuel_counter)
# else
#define scheme_current_thread_ptr (scheme_extension_table->scheme_current_thread_ptr)
#define scheme_fuel_counter_ptr (scheme_extension_table->scheme_fuel_counter_ptr)
# endif
#endif
#define scheme_get_current_thread (scheme_extension_table->scheme_get_current_thread)
#define scheme_is_atomic (scheme_extension_table->scheme_is_atomic)
#define scheme_start_atomic (scheme_extension_table->scheme_start_atomic)
#define scheme_end_atomic (scheme_extension_table->scheme_end_atomic)
#define scheme_end_atomic_no_swap (scheme_extension_table->scheme_end_atomic_no_swap)
#define scheme_start_in_scheduler (scheme_extension_table->scheme_start_in_scheduler)
#define scheme_end_in_scheduler (scheme_extension_table->scheme_end_in_scheduler)
#define scheme_start_atomic_no_break (scheme_extension_table->scheme_start_atomic_no_break)
#define scheme_end_atomic_can_break (scheme_extension_table->scheme_end_atomic_can_break)
#define scheme_out_of_fuel (scheme_extension_table->scheme_out_of_fuel)
#define scheme_thread (scheme_extension_table->scheme_thread)
#define scheme_thread_w_details (scheme_extension_table->scheme_thread_w_details)
#define scheme_kill_thread (scheme_extension_table->scheme_kill_thread)
#define scheme_break_thread (scheme_extension_table->scheme_break_thread)
#define scheme_break_kind_thread (scheme_extension_table->scheme_break_kind_thread)
#define scheme_break_main_thread (scheme_extension_table->scheme_break_main_thread)
#define scheme_break_main_thread_at (scheme_extension_table->scheme_break_main_thread_at)
#define scheme_break_kind_main_thread_at (scheme_extension_table->scheme_break_kind_main_thread_at)
#define scheme_get_main_thread_break_handle (scheme_extension_table->scheme_get_main_thread_break_handle)
#define scheme_set_break_main_target (scheme_extension_table->scheme_set_break_main_target)
#define scheme_thread_block (scheme_extension_table->scheme_thread_block)
#define scheme_thread_block_enable_break (scheme_extension_table->scheme_thread_block_enable_break)
#define scheme_swap_thread (scheme_extension_table->scheme_swap_thread)
#define scheme_making_progress (scheme_extension_table->scheme_making_progress)
#define scheme_weak_suspend_thread (scheme_extension_table->scheme_weak_suspend_thread)
#define scheme_weak_resume_thread (scheme_extension_table->scheme_weak_resume_thread)
#define scheme_block_until (scheme_extension_table->scheme_block_until)
#define scheme_block_until_enable_break (scheme_extension_table->scheme_block_until_enable_break)
#define scheme_block_until_unless (scheme_extension_table->scheme_block_until_unless)
#define scheme_wait_input_allowed (scheme_extension_table->scheme_wait_input_allowed)
#define scheme_unless_ready (scheme_extension_table->scheme_unless_ready)
#define scheme_in_main_thread (scheme_extension_table->scheme_in_main_thread)
#define scheme_cancel_sleep (scheme_extension_table->scheme_cancel_sleep)
#define scheme_start_sleeper_thread (scheme_extension_table->scheme_start_sleeper_thread)
#define scheme_end_sleeper_thread (scheme_extension_table->scheme_end_sleeper_thread)
#define scheme_set_place_sleep (scheme_extension_table->scheme_set_place_sleep)
#define scheme_notify_sleep_progress (scheme_extension_table->scheme_notify_sleep_progress)
#define scheme_make_thread_cell (scheme_extension_table->scheme_make_thread_cell)
#define scheme_thread_cell_get (scheme_extension_table->scheme_thread_cell_get)
#define scheme_thread_cell_set (scheme_extension_table->scheme_thread_cell_set)
#define scheme_tls_allocate (scheme_extension_table->scheme_tls_allocate)
#define scheme_tls_set (scheme_extension_table->scheme_tls_set)
#define scheme_tls_get (scheme_extension_table->scheme_tls_get)
#define scheme_make_custodian (scheme_extension_table->scheme_make_custodian)
#define scheme_add_managed (scheme_extension_table->scheme_add_managed)
#define scheme_add_managed_close_on_exit (scheme_extension_table->scheme_add_managed_close_on_exit)
#define scheme_custodian_check_available (scheme_extension_table->scheme_custodian_check_available)
#define scheme_custodian_is_available (scheme_extension_table->scheme_custodian_is_available)
#define scheme_remove_managed (scheme_extension_table->scheme_remove_managed)
#define scheme_close_managed (scheme_extension_table->scheme_close_managed)
#define scheme_schedule_custodian_close (scheme_extension_table->scheme_schedule_custodian_close)
#define scheme_add_custodian_extractor (scheme_extension_table->scheme_add_custodian_extractor)
#define scheme_flush_managed (scheme_extension_table->scheme_flush_managed)
#define scheme_add_flush (scheme_extension_table->scheme_add_flush)
#define scheme_remove_flush (scheme_extension_table->scheme_remove_flush)
#define scheme_add_atexit_closer (scheme_extension_table->scheme_add_atexit_closer)
#define scheme_atexit (scheme_extension_table->scheme_atexit)
#define scheme_add_evt (scheme_extension_table->scheme_add_evt)
#define scheme_add_evt_through_sema (scheme_extension_table->scheme_add_evt_through_sema)
#define scheme_is_evt (scheme_extension_table->scheme_is_evt)
#define scheme_sync (scheme_extension_table->scheme_sync)
#define scheme_sync_enable_break (scheme_extension_table->scheme_sync_enable_break)
#define scheme_sync_timeout (scheme_extension_table->scheme_sync_timeout)
#define scheme_make_evt_set (scheme_extension_table->scheme_make_evt_set)
#define scheme_add_swap_callback (scheme_extension_table->scheme_add_swap_callback)
#define scheme_add_swap_out_callback (scheme_extension_table->scheme_add_swap_out_callback)
#define scheme_call_enable_break (scheme_extension_table->scheme_call_enable_break)
#define scheme_close_should_force_port_closed (scheme_extension_table->scheme_close_should_force_port_closed)
#define scheme_push_kill_action (scheme_extension_table->scheme_push_kill_action)
#define scheme_pop_kill_action (scheme_extension_table->scheme_pop_kill_action)
#define scheme_set_can_break (scheme_extension_table->scheme_set_can_break)
#define scheme_push_break_enable (scheme_extension_table->scheme_push_break_enable)
#define scheme_pop_break_enable (scheme_extension_table->scheme_pop_break_enable)
#define scheme_abort_continuation_no_dws (scheme_extension_table->scheme_abort_continuation_no_dws)
#define scheme_call_with_composable_no_dws (scheme_extension_table->scheme_call_with_composable_no_dws)
#define scheme_set_on_atomic_timeout (scheme_extension_table->scheme_set_on_atomic_timeout)
#define scheme_signal_error (scheme_extension_table->scheme_signal_error)
#define scheme_raise_exn (scheme_extension_table->scheme_raise_exn)
#define scheme_warning (scheme_extension_table->scheme_warning)
#define scheme_raise (scheme_extension_table->scheme_raise)
#define scheme_log_level_p (scheme_extension_table->scheme_log_level_p)
#define scheme_log (scheme_extension_table->scheme_log)
#define scheme_log_w_data (scheme_extension_table->scheme_log_w_data)
#define scheme_log_message (scheme_extension_table->scheme_log_message)
#define scheme_log_name_message (scheme_extension_table->scheme_log_name_message)
#define scheme_log_name_pfx_message (scheme_extension_table->scheme_log_name_pfx_message)
#define scheme_log_abort (scheme_extension_table->scheme_log_abort)
#define scheme_log_warning (scheme_extension_table->scheme_log_warning)
#define scheme_glib_log_message (scheme_extension_table->scheme_glib_log_message)
#define scheme_glib_log_message_test (scheme_extension_table->scheme_glib_log_message_test)
#define scheme_out_of_memory_abort (scheme_extension_table->scheme_out_of_memory_abort)
#define scheme_wrong_count (scheme_extension_table->scheme_wrong_count)
#define scheme_wrong_count_m (scheme_extension_table->scheme_wrong_count_m)
#define scheme_case_lambda_wrong_count (scheme_extension_table->scheme_case_lambda_wrong_count)
#define scheme_wrong_type (scheme_extension_table->scheme_wrong_type)
#define scheme_wrong_contract (scheme_extension_table->scheme_wrong_contract)
#define scheme_wrong_field_type (scheme_extension_table->scheme_wrong_field_type)
#define scheme_wrong_field_contract (scheme_extension_table->scheme_wrong_field_contract)
#define scheme_arg_mismatch (scheme_extension_table->scheme_arg_mismatch)
#define scheme_contract_error (scheme_extension_table->scheme_contract_error)
#define scheme_wrong_return_arity (scheme_extension_table->scheme_wrong_return_arity)
#define scheme_unbound_global (scheme_extension_table->scheme_unbound_global)
#define scheme_dynamic_wind (scheme_extension_table->scheme_dynamic_wind)
#define scheme_make_type (scheme_extension_table->scheme_make_type)
#define scheme_get_type_name (scheme_extension_table->scheme_get_type_name)
#define scheme_get_type_name_or_null (scheme_extension_table->scheme_get_type_name_or_null)
#define scheme_eof (scheme_extension_table->scheme_eof)
#define scheme_make_eof (scheme_extension_table->scheme_make_eof)
#define scheme_null (scheme_extension_table->scheme_null)
#define scheme_make_null (scheme_extension_table->scheme_make_null)
#define scheme_true (scheme_extension_table->scheme_true)
#define scheme_make_true (scheme_extension_table->scheme_make_true)
#define scheme_false (scheme_extension_table->scheme_false)
#define scheme_make_false (scheme_extension_table->scheme_make_false)
#define scheme_void (scheme_extension_table->scheme_void)
#define scheme_make_void (scheme_extension_table->scheme_make_void)
#define scheme_undefined (scheme_extension_table->scheme_undefined)
#define scheme_tail_call_waiting (scheme_extension_table->scheme_tail_call_waiting)
#define scheme_multiple_values (scheme_extension_table->scheme_multiple_values)
#define scheme_uchar_table (scheme_extension_table->scheme_uchar_table)
#define scheme_uchar_cases_table (scheme_extension_table->scheme_uchar_cases_table)
#define scheme_uchar_cats_table (scheme_extension_table->scheme_uchar_cats_table)
#define scheme_uchar_ups (scheme_extension_table->scheme_uchar_ups)
#define scheme_uchar_downs (scheme_extension_table->scheme_uchar_downs)
#define scheme_uchar_titles (scheme_extension_table->scheme_uchar_titles)
#define scheme_uchar_folds (scheme_extension_table->scheme_uchar_folds)
#define scheme_uchar_combining_classes (scheme_extension_table->scheme_uchar_combining_classes)
#define scheme_on_demand_jit_code (scheme_extension_table->scheme_on_demand_jit_code)
#define scheme_eval (scheme_extension_table->scheme_eval)
#define scheme_eval_multi (scheme_extension_table->scheme_eval_multi)
#define scheme_eval_with_prompt (scheme_extension_table->scheme_eval_with_prompt)
#define scheme_eval_multi_with_prompt (scheme_extension_table->scheme_eval_multi_with_prompt)
#define scheme_eval_compiled (scheme_extension_table->scheme_eval_compiled)
#define scheme_eval_compiled_multi (scheme_extension_table->scheme_eval_compiled_multi)
#define _scheme_eval_compiled (scheme_extension_table->_scheme_eval_compiled)
#define _scheme_eval_compiled_multi (scheme_extension_table->_scheme_eval_compiled_multi)
#define scheme_apply (scheme_extension_table->scheme_apply)
#define scheme_apply_multi (scheme_extension_table->scheme_apply_multi)
#define scheme_apply_no_eb (scheme_extension_table->scheme_apply_no_eb)
#define scheme_apply_multi_no_eb (scheme_extension_table->scheme_apply_multi_no_eb)
#define scheme_apply_to_list (scheme_extension_table->scheme_apply_to_list)
#define scheme_apply_with_prompt (scheme_extension_table->scheme_apply_with_prompt)
#define scheme_apply_multi_with_prompt (scheme_extension_table->scheme_apply_multi_with_prompt)
#define _scheme_apply_with_prompt (scheme_extension_table->_scheme_apply_with_prompt)
#define _scheme_apply_multi_with_prompt (scheme_extension_table->_scheme_apply_multi_with_prompt)
#define scheme_eval_string (scheme_extension_table->scheme_eval_string)
#define scheme_eval_string_multi (scheme_extension_table->scheme_eval_string_multi)
#define scheme_eval_string_all (scheme_extension_table->scheme_eval_string_all)
#define scheme_eval_string_with_prompt (scheme_extension_table->scheme_eval_string_with_prompt)
#define scheme_eval_string_multi_with_prompt (scheme_extension_table->scheme_eval_string_multi_with_prompt)
#define scheme_eval_string_all_with_prompt (scheme_extension_table->scheme_eval_string_all_with_prompt)
#define scheme_eval_all_with_prompt (scheme_extension_table->scheme_eval_all_with_prompt)
#define scheme_eval_module_string (scheme_extension_table->scheme_eval_module_string)
#define _scheme_apply_known_prim_closure (scheme_extension_table->_scheme_apply_known_prim_closure)
#define _scheme_apply_known_prim_closure_multi (scheme_extension_table->_scheme_apply_known_prim_closure_multi)
#define _scheme_apply_prim_closure (scheme_extension_table->_scheme_apply_prim_closure)
#define _scheme_apply_prim_closure_multi (scheme_extension_table->_scheme_apply_prim_closure_multi)
#define scheme_current_argument_stack (scheme_extension_table->scheme_current_argument_stack)
#define scheme_call_with_prompt (scheme_extension_table->scheme_call_with_prompt)
#define scheme_call_with_prompt_multi (scheme_extension_table->scheme_call_with_prompt_multi)
#define _scheme_call_with_prompt (scheme_extension_table->_scheme_call_with_prompt)
#define _scheme_call_with_prompt_multi (scheme_extension_table->_scheme_call_with_prompt_multi)
#define scheme_values (scheme_extension_table->scheme_values)
#define scheme_check_one_value (scheme_extension_table->scheme_check_one_value)
#define scheme_tail_apply (scheme_extension_table->scheme_tail_apply)
#define scheme_tail_apply_no_copy (scheme_extension_table->scheme_tail_apply_no_copy)
#define scheme_tail_apply_to_list (scheme_extension_table->scheme_tail_apply_to_list)
#define scheme_tail_eval_expr (scheme_extension_table->scheme_tail_eval_expr)
#define scheme_set_tail_buffer_size (scheme_extension_table->scheme_set_tail_buffer_size)
#define scheme_force_value (scheme_extension_table->scheme_force_value)
#define scheme_force_one_value (scheme_extension_table->scheme_force_one_value)
#define scheme_ignore_result (scheme_extension_table->scheme_ignore_result)
#define scheme_set_cont_mark (scheme_extension_table->scheme_set_cont_mark)
#define scheme_push_continuation_frame (scheme_extension_table->scheme_push_continuation_frame)
#define scheme_pop_continuation_frame (scheme_extension_table->scheme_pop_continuation_frame)
#define scheme_temp_dec_mark_depth (scheme_extension_table->scheme_temp_dec_mark_depth)
#define scheme_temp_inc_mark_depth (scheme_extension_table->scheme_temp_inc_mark_depth)
#define scheme_current_continuation_marks (scheme_extension_table->scheme_current_continuation_marks)
#define scheme_extract_one_cc_mark (scheme_extension_table->scheme_extract_one_cc_mark)
#define scheme_extract_one_cc_mark_to_tag (scheme_extension_table->scheme_extract_one_cc_mark_to_tag)
#define scheme_do_eval (scheme_extension_table->scheme_do_eval)
#define scheme_detach_multple_array (scheme_extension_table->scheme_detach_multple_array)
#ifndef SCHEME_NO_GC
# ifndef SCHEME_NO_GC_PROTO
#define GC_malloc (scheme_extension_table->GC_malloc)
#define GC_malloc_atomic (scheme_extension_table->GC_malloc_atomic)
#  ifdef MZ_PRECISE_GC
#define GC_malloc_one_tagged (scheme_extension_table->GC_malloc_one_tagged)
#define GC_malloc_atomic_uncollectable (scheme_extension_table->GC_malloc_atomic_uncollectable)
#define scheme_malloc_uncollectable (scheme_extension_table->scheme_malloc_uncollectable)
#define GC_malloc_allow_interior (scheme_extension_table->GC_malloc_allow_interior)
#define GC_malloc_atomic_allow_interior (scheme_extension_table->GC_malloc_atomic_allow_interior)
#define GC_malloc_tagged_allow_interior (scheme_extension_table->GC_malloc_tagged_allow_interior)
#  else
#define GC_malloc_stubborn (scheme_extension_table->GC_malloc_stubborn)
#define GC_malloc_uncollectable (scheme_extension_table->GC_malloc_uncollectable)
#  endif
# endif
#endif
#define scheme_malloc_code (scheme_extension_table->scheme_malloc_code)
#define scheme_malloc_permanent_code (scheme_extension_table->scheme_malloc_permanent_code)
#define scheme_free_code (scheme_extension_table->scheme_free_code)
#ifndef MZ_PRECISE_GC
#define scheme_malloc_gcable_code (scheme_extension_table->scheme_malloc_gcable_code)
#endif
#define scheme_malloc_eternal (scheme_extension_table->scheme_malloc_eternal)
#define scheme_end_stubborn_change (scheme_extension_table->scheme_end_stubborn_change)
#define scheme_calloc (scheme_extension_table->scheme_calloc)
#define scheme_strdup (scheme_extension_table->scheme_strdup)
#define scheme_strdup_eternal (scheme_extension_table->scheme_strdup_eternal)
#define scheme_malloc_fail_ok (scheme_extension_table->scheme_malloc_fail_ok)
#ifndef MZ_PRECISE_GC
#define scheme_late_weak_reference (scheme_extension_table->scheme_late_weak_reference)
#define scheme_late_weak_reference_indirect (scheme_extension_table->scheme_late_weak_reference_indirect)
#define scheme_weak_reference (scheme_extension_table->scheme_weak_reference)
#define scheme_weak_reference_indirect (scheme_extension_table->scheme_weak_reference_indirect)
#define scheme_unweak_reference (scheme_extension_table->scheme_unweak_reference)
#endif
#define scheme_add_finalizer (scheme_extension_table->scheme_add_finalizer)
#define scheme_add_finalizer_once (scheme_extension_table->scheme_add_finalizer_once)
#define scheme_subtract_finalizer (scheme_extension_table->scheme_subtract_finalizer)
#define scheme_add_scheme_finalizer (scheme_extension_table->scheme_add_scheme_finalizer)
#define scheme_add_scheme_finalizer_once (scheme_extension_table->scheme_add_scheme_finalizer_once)
#define scheme_register_finalizer (scheme_extension_table->scheme_register_finalizer)
#define scheme_remove_all_finalization (scheme_extension_table->scheme_remove_all_finalization)
#define scheme_dont_gc_ptr (scheme_extension_table->scheme_dont_gc_ptr)
#define scheme_gc_ptr_ok (scheme_extension_table->scheme_gc_ptr_ok)
#define scheme_collect_garbage (scheme_extension_table->scheme_collect_garbage)
#define scheme_collect_garbage_minor (scheme_extension_table->scheme_collect_garbage_minor)
#define scheme_enable_garbage_collection (scheme_extension_table->scheme_enable_garbage_collection)
#define scheme_incremental_garbage_collection (scheme_extension_table->scheme_incremental_garbage_collection)
#ifdef MZ_PRECISE_GC
# ifndef USE_THREAD_LOCAL
#define GC_variable_stack (scheme_extension_table->GC_variable_stack)
# endif
#define GC_register_traversers (scheme_extension_table->GC_register_traversers)
#define GC_resolve (scheme_extension_table->GC_resolve)
#define GC_mark (scheme_extension_table->GC_mark)
#define GC_fixup (scheme_extension_table->GC_fixup)
#define GC_fixup_self (scheme_extension_table->GC_fixup_self)
#endif
#define scheme_malloc_immobile_box (scheme_extension_table->scheme_malloc_immobile_box)
#define scheme_free_immobile_box (scheme_extension_table->scheme_free_immobile_box)
#define scheme_add_gc_callback (scheme_extension_table->scheme_add_gc_callback)
#define scheme_remove_gc_callback (scheme_extension_table->scheme_remove_gc_callback)
#define scheme_register_type_gc_shape (scheme_extension_table->scheme_register_type_gc_shape)
#define scheme_make_bucket_table (scheme_extension_table->scheme_make_bucket_table)
#define scheme_add_to_table (scheme_extension_table->scheme_add_to_table)
#define scheme_change_in_table (scheme_extension_table->scheme_change_in_table)
#define scheme_lookup_in_table (scheme_extension_table->scheme_lookup_in_table)
#define scheme_bucket_from_table (scheme_extension_table->scheme_bucket_from_table)
#define scheme_bucket_table_equal (scheme_extension_table->scheme_bucket_table_equal)
#define scheme_clone_bucket_table (scheme_extension_table->scheme_clone_bucket_table)
#define scheme_clear_bucket_table (scheme_extension_table->scheme_clear_bucket_table)
#define scheme_bucket_table_index (scheme_extension_table->scheme_bucket_table_index)
#define scheme_bucket_table_next (scheme_extension_table->scheme_bucket_table_next)
#define scheme_make_hash_table (scheme_extension_table->scheme_make_hash_table)
#define scheme_make_hash_table_equal (scheme_extension_table->scheme_make_hash_table_equal)
#define scheme_make_hash_table_eqv (scheme_extension_table->scheme_make_hash_table_eqv)
#define scheme_hash_set (scheme_extension_table->scheme_hash_set)
#define scheme_hash_get (scheme_extension_table->scheme_hash_get)
#define scheme_eq_hash_get (scheme_extension_table->scheme_eq_hash_get)
#define scheme_hash_set_atomic (scheme_extension_table->scheme_hash_set_atomic)
#define scheme_hash_get_atomic (scheme_extension_table->scheme_hash_get_atomic)
#define scheme_hash_table_equal (scheme_extension_table->scheme_hash_table_equal)
#define scheme_is_hash_table_equal (scheme_extension_table->scheme_is_hash_table_equal)
#define scheme_is_hash_table_eqv (scheme_extension_table->scheme_is_hash_table_eqv)
#define scheme_clone_hash_table (scheme_extension_table->scheme_clone_hash_table)
#define scheme_clear_hash_table (scheme_extension_table->scheme_clear_hash_table)
#define scheme_hash_table_index (scheme_extension_table->scheme_hash_table_index)
#define scheme_hash_table_next (scheme_extension_table->scheme_hash_table_next)
#define scheme_make_hash_tree (scheme_extension_table->scheme_make_hash_tree)
#define scheme_hash_tree_set (scheme_extension_table->scheme_hash_tree_set)
#define scheme_hash_tree_get (scheme_extension_table->scheme_hash_tree_get)
#define scheme_eq_hash_tree_get (scheme_extension_table->scheme_eq_hash_tree_get)
#define scheme_hash_tree_next (scheme_extension_table->scheme_hash_tree_next)
#define scheme_hash_tree_index (scheme_extension_table->scheme_hash_tree_index)
#define scheme_hash_tree_equal (scheme_extension_table->scheme_hash_tree_equal)
#define scheme_is_hash_tree_equal (scheme_extension_table->scheme_is_hash_tree_equal)
#define scheme_is_hash_tree_eqv (scheme_extension_table->scheme_is_hash_tree_eqv)
#define scheme_make_prim (scheme_extension_table->scheme_make_prim)
#define scheme_make_noneternal_prim (scheme_extension_table->scheme_make_noneternal_prim)
#define scheme_make_prim_w_arity (scheme_extension_table->scheme_make_prim_w_arity)
#define scheme_make_folding_prim (scheme_extension_table->scheme_make_folding_prim)
#define scheme_make_immed_prim (scheme_extension_table->scheme_make_immed_prim)
#define scheme_make_noncm_prim (scheme_extension_table->scheme_make_noncm_prim)
#define scheme_make_noneternal_prim_w_arity (scheme_extension_table->scheme_make_noneternal_prim_w_arity)
#define scheme_make_prim_w_everything (scheme_extension_table->scheme_make_prim_w_everything)
#define scheme_make_prim_closure_w_arity (scheme_extension_table->scheme_make_prim_closure_w_arity)
#define scheme_make_folding_prim_closure (scheme_extension_table->scheme_make_folding_prim_closure)
#define scheme_make_closed_prim (scheme_extension_table->scheme_make_closed_prim)
#define scheme_make_closed_prim_w_arity (scheme_extension_table->scheme_make_closed_prim_w_arity)
#define scheme_make_folding_closed_prim (scheme_extension_table->scheme_make_folding_closed_prim)
#define scheme_make_closed_prim_w_everything (scheme_extension_table->scheme_make_closed_prim_w_everything)
#define scheme_prim_is_method (scheme_extension_table->scheme_prim_is_method)
#define scheme_make_pair (scheme_extension_table->scheme_make_pair)
#define scheme_make_mutable_pair (scheme_extension_table->scheme_make_mutable_pair)
#define scheme_make_list_pair (scheme_extension_table->scheme_make_list_pair)
#define scheme_make_raw_pair (scheme_extension_table->scheme_make_raw_pair)
#define scheme_make_byte_string (scheme_extension_table->scheme_make_byte_string)
#define scheme_make_sized_byte_string (scheme_extension_table->scheme_make_sized_byte_string)
#define scheme_make_sized_offset_byte_string (scheme_extension_table->scheme_make_sized_offset_byte_string)
#define scheme_make_immutable_sized_byte_string (scheme_extension_table->scheme_make_immutable_sized_byte_string)
#define scheme_make_byte_string_without_copying (scheme_extension_table->scheme_make_byte_string_without_copying)
#define scheme_alloc_byte_string (scheme_extension_table->scheme_alloc_byte_string)
#define scheme_append_byte_string (scheme_extension_table->scheme_append_byte_string)
#define scheme_make_utf8_string (scheme_extension_table->scheme_make_utf8_string)
#define scheme_make_sized_utf8_string (scheme_extension_table->scheme_make_sized_utf8_string)
#define scheme_make_sized_offset_utf8_string (scheme_extension_table->scheme_make_sized_offset_utf8_string)
#define scheme_make_immutable_sized_utf8_string (scheme_extension_table->scheme_make_immutable_sized_utf8_string)
#define scheme_make_locale_string (scheme_extension_table->scheme_make_locale_string)
#define scheme_char_string_to_byte_string (scheme_extension_table->scheme_char_string_to_byte_string)
#define scheme_byte_string_to_char_string (scheme_extension_table->scheme_byte_string_to_char_string)
#define scheme_char_string_to_byte_string_locale (scheme_extension_table->scheme_char_string_to_byte_string_locale)
#define scheme_byte_string_to_char_string_locale (scheme_extension_table->scheme_byte_string_to_char_string_locale)
#define scheme_char_string_to_path (scheme_extension_table->scheme_char_string_to_path)
#define scheme_path_to_char_string (scheme_extension_table->scheme_path_to_char_string)
#define scheme_make_char_string (scheme_extension_table->scheme_make_char_string)
#define scheme_make_sized_char_string (scheme_extension_table->scheme_make_sized_char_string)
#define scheme_make_sized_offset_char_string (scheme_extension_table->scheme_make_sized_offset_char_string)
#define scheme_make_immutable_sized_char_string (scheme_extension_table->scheme_make_immutable_sized_char_string)
#define scheme_make_char_string_without_copying (scheme_extension_table->scheme_make_char_string_without_copying)
#define scheme_alloc_char_string (scheme_extension_table->scheme_alloc_char_string)
#define scheme_append_char_string (scheme_extension_table->scheme_append_char_string)
#define scheme_string_recase (scheme_extension_table->scheme_string_recase)
#define scheme_make_vector (scheme_extension_table->scheme_make_vector)
#define scheme_alloc_flvector (scheme_extension_table->scheme_alloc_flvector)
#ifdef MZ_LONG_DOUBLE
#define scheme_alloc_extflvector (scheme_extension_table->scheme_alloc_extflvector)
#endif
#define scheme_alloc_fxvector (scheme_extension_table->scheme_alloc_fxvector)
#define scheme_make_integer_value (scheme_extension_table->scheme_make_integer_value)
#define scheme_make_integer_value_from_unsigned (scheme_extension_table->scheme_make_integer_value_from_unsigned)
#define scheme_make_integer_value_from_long_long (scheme_extension_table->scheme_make_integer_value_from_long_long)
#define scheme_make_integer_value_from_unsigned_long_long (scheme_extension_table->scheme_make_integer_value_from_unsigned_long_long)
#define scheme_make_integer_value_from_long_halves (scheme_extension_table->scheme_make_integer_value_from_long_halves)
#define scheme_make_integer_value_from_unsigned_long_halves (scheme_extension_table->scheme_make_integer_value_from_unsigned_long_halves)
#define scheme_make_double (scheme_extension_table->scheme_make_double)
#ifdef MZ_LONG_DOUBLE
#define scheme_make_long_double (scheme_extension_table->scheme_make_long_double)
#endif
#ifdef MZ_USE_SINGLE_FLOATS
#define scheme_make_float (scheme_extension_table->scheme_make_float)
#endif
#define scheme_make_char (scheme_extension_table->scheme_make_char)
#define scheme_make_char_or_nul (scheme_extension_table->scheme_make_char_or_nul)
#define scheme_make_sema (scheme_extension_table->scheme_make_sema)
#define scheme_post_sema (scheme_extension_table->scheme_post_sema)
#define scheme_post_sema_all (scheme_extension_table->scheme_post_sema_all)
#define scheme_wait_sema (scheme_extension_table->scheme_wait_sema)
#define scheme_try_plain_sema (scheme_extension_table->scheme_try_plain_sema)
#define scheme_char_constants (scheme_extension_table->scheme_char_constants)
#define scheme_make_channel (scheme_extension_table->scheme_make_channel)
#define scheme_make_channel_put_evt (scheme_extension_table->scheme_make_channel_put_evt)
#define scheme_get_int_val (scheme_extension_table->scheme_get_int_val)
#define scheme_get_unsigned_int_val (scheme_extension_table->scheme_get_unsigned_int_val)
#define scheme_get_long_long_val (scheme_extension_table->scheme_get_long_long_val)
#define scheme_get_unsigned_long_long_val (scheme_extension_table->scheme_get_unsigned_long_long_val)
#define scheme_real_to_double (scheme_extension_table->scheme_real_to_double)
#ifdef MZ_LONG_DOUBLE
#define scheme_real_to_long_double (scheme_extension_table->scheme_real_to_long_double)
#endif
#define scheme_make_cptr (scheme_extension_table->scheme_make_cptr)
#define scheme_make_offset_cptr (scheme_extension_table->scheme_make_offset_cptr)
#define scheme_make_external_cptr (scheme_extension_table->scheme_make_external_cptr)
#define scheme_make_offset_external_cptr (scheme_extension_table->scheme_make_offset_external_cptr)
#define scheme_is_cpointer (scheme_extension_table->scheme_is_cpointer)
#define scheme_get_proc_name (scheme_extension_table->scheme_get_proc_name)
#define scheme_utf8_decode (scheme_extension_table->scheme_utf8_decode)
#define scheme_utf8_decode_offset_prefix (scheme_extension_table->scheme_utf8_decode_offset_prefix)
#define scheme_utf8_decode_as_prefix (scheme_extension_table->scheme_utf8_decode_as_prefix)
#define scheme_utf8_decode_all (scheme_extension_table->scheme_utf8_decode_all)
#define scheme_utf8_decode_prefix (scheme_extension_table->scheme_utf8_decode_prefix)
#define scheme_utf8_decode_to_buffer (scheme_extension_table->scheme_utf8_decode_to_buffer)
#define scheme_utf8_decode_to_buffer_len (scheme_extension_table->scheme_utf8_decode_to_buffer_len)
#define scheme_utf8_decode_count (scheme_extension_table->scheme_utf8_decode_count)
#define scheme_utf8_encode (scheme_extension_table->scheme_utf8_encode)
#define scheme_utf8_encode_all (scheme_extension_table->scheme_utf8_encode_all)
#define scheme_utf8_encode_to_buffer (scheme_extension_table->scheme_utf8_encode_to_buffer)
#define scheme_utf8_encode_to_buffer_len (scheme_extension_table->scheme_utf8_encode_to_buffer_len)
#define scheme_ucs4_to_utf16 (scheme_extension_table->scheme_ucs4_to_utf16)
#define scheme_utf16_to_ucs4 (scheme_extension_table->scheme_utf16_to_ucs4)
#define scheme_open_converter (scheme_extension_table->scheme_open_converter)
#define scheme_close_converter (scheme_extension_table->scheme_close_converter)
#define scheme_getenv (scheme_extension_table->scheme_getenv)
#define scheme_make_bignum (scheme_extension_table->scheme_make_bignum)
#define scheme_make_bignum_from_unsigned (scheme_extension_table->scheme_make_bignum_from_unsigned)
#define scheme_make_bignum_from_long_long (scheme_extension_table->scheme_make_bignum_from_long_long)
#define scheme_make_bignum_from_unsigned_long_long (scheme_extension_table->scheme_make_bignum_from_unsigned_long_long)
#define scheme_bignum_to_double (scheme_extension_table->scheme_bignum_to_double)
#define scheme_bignum_from_double (scheme_extension_table->scheme_bignum_from_double)
#ifdef MZ_LONG_DOUBLE
#define scheme_bignum_to_long_double (scheme_extension_table->scheme_bignum_to_long_double)
#define scheme_bignum_from_long_double (scheme_extension_table->scheme_bignum_from_long_double)
#endif
#ifdef MZ_USE_SINGLE_FLOATS
#define scheme_bignum_to_float (scheme_extension_table->scheme_bignum_to_float)
#define scheme_bignum_from_float (scheme_extension_table->scheme_bignum_from_float)
#else
# define scheme_bignum_to_float scheme_bignum_to_double
# define scheme_bignum_from_float scheme_bignum_from_double
#endif
#define scheme_bignum_to_string (scheme_extension_table->scheme_bignum_to_string)
#define scheme_bignum_to_allocated_string (scheme_extension_table->scheme_bignum_to_allocated_string)
#define scheme_read_bignum (scheme_extension_table->scheme_read_bignum)
#define scheme_read_bignum_bytes (scheme_extension_table->scheme_read_bignum_bytes)
#define scheme_bignum_normalize (scheme_extension_table->scheme_bignum_normalize)
#define scheme_make_rational (scheme_extension_table->scheme_make_rational)
#define scheme_rational_to_double (scheme_extension_table->scheme_rational_to_double)
#define scheme_rational_from_double (scheme_extension_table->scheme_rational_from_double)
#ifdef MZ_LONG_DOUBLE
#define scheme_rational_to_long_double (scheme_extension_table->scheme_rational_to_long_double)
#define scheme_rational_from_long_double (scheme_extension_table->scheme_rational_from_long_double)
#endif
#ifdef MZ_USE_SINGLE_FLOATS
#define scheme_rational_to_float (scheme_extension_table->scheme_rational_to_float)
#define scheme_rational_from_float (scheme_extension_table->scheme_rational_from_float)
#else
# define scheme_rational_to_float scheme_rational_to_double
# define scheme_rational_from_float scheme_rational_from_double
#endif
#define scheme_rational_normalize (scheme_extension_table->scheme_rational_normalize)
#define scheme_rational_numerator (scheme_extension_table->scheme_rational_numerator)
#define scheme_rational_denominator (scheme_extension_table->scheme_rational_denominator)
#define scheme_make_complex (scheme_extension_table->scheme_make_complex)
#define scheme_complex_normalize (scheme_extension_table->scheme_complex_normalize)
#define scheme_complex_real_part (scheme_extension_table->scheme_complex_real_part)
#define scheme_complex_imaginary_part (scheme_extension_table->scheme_complex_imaginary_part)
#define scheme_is_exact (scheme_extension_table->scheme_is_exact)
#define scheme_is_inexact (scheme_extension_table->scheme_is_inexact)
#define scheme_expand (scheme_extension_table->scheme_expand)
#define scheme_compile (scheme_extension_table->scheme_compile)
#define scheme_read (scheme_extension_table->scheme_read)
#define scheme_read_syntax (scheme_extension_table->scheme_read_syntax)
#define scheme_write (scheme_extension_table->scheme_write)
#define scheme_print (scheme_extension_table->scheme_print)
#define scheme_display (scheme_extension_table->scheme_display)
#define scheme_write_w_max (scheme_extension_table->scheme_write_w_max)
#define scheme_display_w_max (scheme_extension_table->scheme_display_w_max)
#define scheme_print_w_max (scheme_extension_table->scheme_print_w_max)
#define scheme_write_byte_string (scheme_extension_table->scheme_write_byte_string)
#define scheme_write_char_string (scheme_extension_table->scheme_write_char_string)
#define scheme_put_byte_string (scheme_extension_table->scheme_put_byte_string)
#define scheme_put_char_string (scheme_extension_table->scheme_put_char_string)
#define scheme_write_to_string (scheme_extension_table->scheme_write_to_string)
#define scheme_display_to_string (scheme_extension_table->scheme_display_to_string)
#define scheme_print_to_string (scheme_extension_table->scheme_print_to_string)
#define scheme_write_to_string_w_max (scheme_extension_table->scheme_write_to_string_w_max)
#define scheme_display_to_string_w_max (scheme_extension_table->scheme_display_to_string_w_max)
#define scheme_print_to_string_w_max (scheme_extension_table->scheme_print_to_string_w_max)
#define scheme_debug_print (scheme_extension_table->scheme_debug_print)
#define scheme_flush_output (scheme_extension_table->scheme_flush_output)
#define scheme_format (scheme_extension_table->scheme_format)
#define scheme_printf (scheme_extension_table->scheme_printf)
#define scheme_format_utf8 (scheme_extension_table->scheme_format_utf8)
#define scheme_printf_utf8 (scheme_extension_table->scheme_printf_utf8)
#define scheme_getc (scheme_extension_table->scheme_getc)
#define scheme_get_byte (scheme_extension_table->scheme_get_byte)
#define scheme_peekc (scheme_extension_table->scheme_peekc)
#define scheme_peek_byte (scheme_extension_table->scheme_peek_byte)
#define scheme_peekc_skip (scheme_extension_table->scheme_peekc_skip)
#define scheme_peek_byte_skip (scheme_extension_table->scheme_peek_byte_skip)
#define scheme_getc_special_ok (scheme_extension_table->scheme_getc_special_ok)
#define scheme_get_byte_special_ok (scheme_extension_table->scheme_get_byte_special_ok)
#define scheme_peekc_special_ok (scheme_extension_table->scheme_peekc_special_ok)
#define scheme_peek_byte_special_ok_skip (scheme_extension_table->scheme_peek_byte_special_ok_skip)
#define scheme_peekc_special_ok_skip (scheme_extension_table->scheme_peekc_special_ok_skip)
#define scheme_ungetc (scheme_extension_table->scheme_ungetc)
#define scheme_byte_ready (scheme_extension_table->scheme_byte_ready)
#define scheme_char_ready (scheme_extension_table->scheme_char_ready)
#define scheme_peekc_is_ungetc (scheme_extension_table->scheme_peekc_is_ungetc)
#define scheme_need_wakeup (scheme_extension_table->scheme_need_wakeup)
#define scheme_get_byte_string (scheme_extension_table->scheme_get_byte_string)
#define scheme_get_byte_string_unless (scheme_extension_table->scheme_get_byte_string_unless)
#define scheme_get_byte_string_special_ok_unless (scheme_extension_table->scheme_get_byte_string_special_ok_unless)
#define scheme_progress_evt (scheme_extension_table->scheme_progress_evt)
#define scheme_peeked_read (scheme_extension_table->scheme_peeked_read)
#define scheme_get_char_string (scheme_extension_table->scheme_get_char_string)
#define scheme_get_bytes (scheme_extension_table->scheme_get_bytes)
#define scheme_get_ready_special (scheme_extension_table->scheme_get_ready_special)
#define scheme_tell (scheme_extension_table->scheme_tell)
#define scheme_tell_can_redirect (scheme_extension_table->scheme_tell_can_redirect)
#define scheme_output_tell (scheme_extension_table->scheme_output_tell)
#define scheme_tell_line (scheme_extension_table->scheme_tell_line)
#define scheme_tell_column (scheme_extension_table->scheme_tell_column)
#define scheme_tell_all (scheme_extension_table->scheme_tell_all)
#define scheme_set_port_location (scheme_extension_table->scheme_set_port_location)
#define scheme_count_lines (scheme_extension_table->scheme_count_lines)
#define scheme_close_input_port (scheme_extension_table->scheme_close_input_port)
#define scheme_close_output_port (scheme_extension_table->scheme_close_output_port)
#define scheme_write_special (scheme_extension_table->scheme_write_special)
#define scheme_write_special_nonblock (scheme_extension_table->scheme_write_special_nonblock)
#define scheme_make_write_evt (scheme_extension_table->scheme_make_write_evt)
#define scheme_port_record (scheme_extension_table->scheme_port_record)
#define scheme_input_port_record (scheme_extension_table->scheme_input_port_record)
#define scheme_output_port_record (scheme_extension_table->scheme_output_port_record)
#define scheme_is_input_port (scheme_extension_table->scheme_is_input_port)
#define scheme_is_output_port (scheme_extension_table->scheme_is_output_port)
#define scheme_make_port_type (scheme_extension_table->scheme_make_port_type)
#define scheme_make_input_port (scheme_extension_table->scheme_make_input_port)
#define scheme_make_output_port (scheme_extension_table->scheme_make_output_port)
#define scheme_set_next_port_custodian (scheme_extension_table->scheme_set_next_port_custodian)
#define scheme_set_port_location_fun (scheme_extension_table->scheme_set_port_location_fun)
#define scheme_set_port_count_lines_fun (scheme_extension_table->scheme_set_port_count_lines_fun)
#define scheme_port_count_lines (scheme_extension_table->scheme_port_count_lines)
#define scheme_progress_evt_via_get (scheme_extension_table->scheme_progress_evt_via_get)
#define scheme_peeked_read_via_get (scheme_extension_table->scheme_peeked_read_via_get)
#define scheme_write_evt_via_write (scheme_extension_table->scheme_write_evt_via_write)
#define scheme_write_special_evt_via_write_special (scheme_extension_table->scheme_write_special_evt_via_write_special)
#define scheme_open_input_file (scheme_extension_table->scheme_open_input_file)
#define scheme_open_output_file (scheme_extension_table->scheme_open_output_file)
#define scheme_open_input_output_file (scheme_extension_table->scheme_open_input_output_file)
#define scheme_open_output_file_with_mode (scheme_extension_table->scheme_open_output_file_with_mode)
#define scheme_make_file_input_port (scheme_extension_table->scheme_make_file_input_port)
#define scheme_make_named_file_input_port (scheme_extension_table->scheme_make_named_file_input_port)
#define scheme_make_file_output_port (scheme_extension_table->scheme_make_file_output_port)
#define scheme_make_fd_input_port (scheme_extension_table->scheme_make_fd_input_port)
#define scheme_make_fd_output_port (scheme_extension_table->scheme_make_fd_output_port)
#define scheme_make_byte_string_input_port (scheme_extension_table->scheme_make_byte_string_input_port)
#define scheme_make_sized_byte_string_input_port (scheme_extension_table->scheme_make_sized_byte_string_input_port)
#define scheme_make_byte_string_output_port (scheme_extension_table->scheme_make_byte_string_output_port)
#define scheme_get_sized_byte_string_output (scheme_extension_table->scheme_get_sized_byte_string_output)
#define scheme_get_reset_sized_byte_string_output (scheme_extension_table->scheme_get_reset_sized_byte_string_output)
#define scheme_pipe (scheme_extension_table->scheme_pipe)
#define scheme_pipe_with_limit (scheme_extension_table->scheme_pipe_with_limit)
#define scheme_make_null_output_port (scheme_extension_table->scheme_make_null_output_port)
#define scheme_make_redirect_output_port (scheme_extension_table->scheme_make_redirect_output_port)
#define scheme_set_file_position (scheme_extension_table->scheme_set_file_position)
#define scheme_file_exists (scheme_extension_table->scheme_file_exists)
#define scheme_directory_exists (scheme_extension_table->scheme_directory_exists)
#define scheme_expand_filename (scheme_extension_table->scheme_expand_filename)
#define scheme_expand_user_filename (scheme_extension_table->scheme_expand_user_filename)
#define scheme_expand_string_filename (scheme_extension_table->scheme_expand_string_filename)
#define scheme_os_getcwd (scheme_extension_table->scheme_os_getcwd)
#define scheme_os_setcwd (scheme_extension_table->scheme_os_setcwd)
#define scheme_getdrive (scheme_extension_table->scheme_getdrive)
#define scheme_split_path (scheme_extension_table->scheme_split_path)
#define scheme_build_path (scheme_extension_table->scheme_build_path)
#define scheme_path_to_directory_path (scheme_extension_table->scheme_path_to_directory_path)
#define scheme_path_to_complete_path (scheme_extension_table->scheme_path_to_complete_path)
#define scheme_simplify_path (scheme_extension_table->scheme_simplify_path)
#define scheme_make_path (scheme_extension_table->scheme_make_path)
#define scheme_make_sized_path (scheme_extension_table->scheme_make_sized_path)
#define scheme_make_sized_offset_path (scheme_extension_table->scheme_make_sized_offset_path)
#define scheme_make_sized_offset_kind_path (scheme_extension_table->scheme_make_sized_offset_kind_path)
#define scheme_make_path_without_copying (scheme_extension_table->scheme_make_path_without_copying)
#define scheme_alloc_fdset_array (scheme_extension_table->scheme_alloc_fdset_array)
#define scheme_init_fdset_array (scheme_extension_table->scheme_init_fdset_array)
#define scheme_get_fdset (scheme_extension_table->scheme_get_fdset)
#define scheme_fdzero (scheme_extension_table->scheme_fdzero)
#define scheme_fdset (scheme_extension_table->scheme_fdset)
#define scheme_fdclr (scheme_extension_table->scheme_fdclr)
#define scheme_fdisset (scheme_extension_table->scheme_fdisset)
#define scheme_add_fd_handle (scheme_extension_table->scheme_add_fd_handle)
#define scheme_add_fd_eventmask (scheme_extension_table->scheme_add_fd_eventmask)
#define scheme_collapse_win_fd (scheme_extension_table->scheme_collapse_win_fd)
#define scheme_set_wakeup_time (scheme_extension_table->scheme_set_wakeup_time)
#define scheme_security_check_file (scheme_extension_table->scheme_security_check_file)
#define scheme_security_check_file_link (scheme_extension_table->scheme_security_check_file_link)
#define scheme_security_check_network (scheme_extension_table->scheme_security_check_network)
#define scheme_get_host_address (scheme_extension_table->scheme_get_host_address)
#define scheme_free_host_address (scheme_extension_table->scheme_free_host_address)
#define scheme_host_address_strerror (scheme_extension_table->scheme_host_address_strerror)
#define scheme_getnameinfo (scheme_extension_table->scheme_getnameinfo)
#define scheme_get_port_file_descriptor (scheme_extension_table->scheme_get_port_file_descriptor)
#define scheme_get_port_fd (scheme_extension_table->scheme_get_port_fd)
#define scheme_get_port_socket (scheme_extension_table->scheme_get_port_socket)
#define scheme_socket_to_ports (scheme_extension_table->scheme_socket_to_ports)
#define scheme_fd_to_semaphore (scheme_extension_table->scheme_fd_to_semaphore)
#define scheme_set_type_printer (scheme_extension_table->scheme_set_type_printer)
#define scheme_print_bytes (scheme_extension_table->scheme_print_bytes)
#define scheme_print_utf8 (scheme_extension_table->scheme_print_utf8)
#define scheme_print_string (scheme_extension_table->scheme_print_string)
#define scheme_read_byte_string (scheme_extension_table->scheme_read_byte_string)
#define scheme_make_namespace (scheme_extension_table->scheme_make_namespace)
#define scheme_add_global (scheme_extension_table->scheme_add_global)
#define scheme_add_global_symbol (scheme_extension_table->scheme_add_global_symbol)
#define scheme_make_envunbox (scheme_extension_table->scheme_make_envunbox)
#define scheme_lookup_global (scheme_extension_table->scheme_lookup_global)
#define scheme_global_bucket (scheme_extension_table->scheme_global_bucket)
#define scheme_module_bucket (scheme_extension_table->scheme_module_bucket)
#define scheme_builtin_value (scheme_extension_table->scheme_builtin_value)
#define scheme_set_global_bucket (scheme_extension_table->scheme_set_global_bucket)
#define scheme_primitive_module (scheme_extension_table->scheme_primitive_module)
#define scheme_finish_primitive_module (scheme_extension_table->scheme_finish_primitive_module)
#define scheme_set_primitive_module_phaseless (scheme_extension_table->scheme_set_primitive_module_phaseless)
#define scheme_protect_primitive_provide (scheme_extension_table->scheme_protect_primitive_provide)
#define scheme_make_modidx (scheme_extension_table->scheme_make_modidx)
#define scheme_dynamic_require (scheme_extension_table->scheme_dynamic_require)
#define scheme_dynamic_require_reader (scheme_extension_table->scheme_dynamic_require_reader)
#define scheme_namespace_require (scheme_extension_table->scheme_namespace_require)
#define scheme_is_module_path (scheme_extension_table->scheme_is_module_path)
#define scheme_is_module_path_index (scheme_extension_table->scheme_is_module_path_index)
#define scheme_is_resolved_module_path (scheme_extension_table->scheme_is_resolved_module_path)
#define scheme_datum_to_kernel_stx (scheme_extension_table->scheme_datum_to_kernel_stx)
#define scheme_module_is_declared (scheme_extension_table->scheme_module_is_declared)
#define scheme_intern_symbol (scheme_extension_table->scheme_intern_symbol)
#define scheme_intern_exact_symbol (scheme_extension_table->scheme_intern_exact_symbol)
#define scheme_intern_exact_char_symbol (scheme_extension_table->scheme_intern_exact_char_symbol)
#define scheme_make_symbol (scheme_extension_table->scheme_make_symbol)
#define scheme_make_exact_symbol (scheme_extension_table->scheme_make_exact_symbol)
#define scheme_make_exact_char_symbol (scheme_extension_table->scheme_make_exact_char_symbol)
#define scheme_symbol_name (scheme_extension_table->scheme_symbol_name)
#define scheme_symbol_name_and_size (scheme_extension_table->scheme_symbol_name_and_size)
#define scheme_symbol_val (scheme_extension_table->scheme_symbol_val)
#define scheme_intern_exact_keyword (scheme_extension_table->scheme_intern_exact_keyword)
#define scheme_intern_exact_char_keyword (scheme_extension_table->scheme_intern_exact_char_keyword)
#define scheme_make_struct_values (scheme_extension_table->scheme_make_struct_values)
#define scheme_make_struct_names (scheme_extension_table->scheme_make_struct_names)
#define scheme_make_struct_type (scheme_extension_table->scheme_make_struct_type)
#define scheme_make_struct_type2 (scheme_extension_table->scheme_make_struct_type2)
#define scheme_make_struct_instance (scheme_extension_table->scheme_make_struct_instance)
#define scheme_is_struct_instance (scheme_extension_table->scheme_is_struct_instance)
#define scheme_struct_ref (scheme_extension_table->scheme_struct_ref)
#define scheme_struct_set (scheme_extension_table->scheme_struct_set)
#define scheme_make_struct_type_property (scheme_extension_table->scheme_make_struct_type_property)
#define scheme_make_struct_type_property_w_guard (scheme_extension_table->scheme_make_struct_type_property_w_guard)
#define scheme_struct_type_property_ref (scheme_extension_table->scheme_struct_type_property_ref)
#define scheme_chaperone_struct_type_property_ref (scheme_extension_table->scheme_chaperone_struct_type_property_ref)
#define scheme_make_location (scheme_extension_table->scheme_make_location)
#define scheme_is_location (scheme_extension_table->scheme_is_location)
#define scheme_make_inspector (scheme_extension_table->scheme_make_inspector)
#define scheme_is_subinspector (scheme_extension_table->scheme_is_subinspector)
#define scheme_eq (scheme_extension_table->scheme_eq)
#define scheme_eqv (scheme_extension_table->scheme_eqv)
#define scheme_equal (scheme_extension_table->scheme_equal)
#define scheme_chaperone_of (scheme_extension_table->scheme_chaperone_of)
#define scheme_impersonator_of (scheme_extension_table->scheme_impersonator_of)
#ifdef MZ_PRECISE_GC
#define scheme_hash_key (scheme_extension_table->scheme_hash_key)
#endif
#define scheme_equal_hash_key (scheme_extension_table->scheme_equal_hash_key)
#define scheme_equal_hash_key2 (scheme_extension_table->scheme_equal_hash_key2)
#define scheme_recur_equal_hash_key (scheme_extension_table->scheme_recur_equal_hash_key)
#define scheme_recur_equal_hash_key2 (scheme_extension_table->scheme_recur_equal_hash_key2)
#define scheme_eqv_hash_key (scheme_extension_table->scheme_eqv_hash_key)
#define scheme_eqv_hash_key2 (scheme_extension_table->scheme_eqv_hash_key2)
#define scheme_set_type_equality (scheme_extension_table->scheme_set_type_equality)
#define scheme_recur_equal (scheme_extension_table->scheme_recur_equal)
#define scheme_build_list (scheme_extension_table->scheme_build_list)
#define scheme_build_list_offset (scheme_extension_table->scheme_build_list_offset)
#define scheme_is_list (scheme_extension_table->scheme_is_list)
#define scheme_list_length (scheme_extension_table->scheme_list_length)
#define scheme_proper_list_length (scheme_extension_table->scheme_proper_list_length)
#define scheme_alloc_list (scheme_extension_table->scheme_alloc_list)
#define scheme_map_1 (scheme_extension_table->scheme_map_1)
#define scheme_car (scheme_extension_table->scheme_car)
#define scheme_cdr (scheme_extension_table->scheme_cdr)
#define scheme_cadr (scheme_extension_table->scheme_cadr)
#define scheme_caddr (scheme_extension_table->scheme_caddr)
#define scheme_vector_to_list (scheme_extension_table->scheme_vector_to_list)
#define scheme_list_to_vector (scheme_extension_table->scheme_list_to_vector)
#define scheme_append (scheme_extension_table->scheme_append)
#define scheme_reverse (scheme_extension_table->scheme_reverse)
#define scheme_box (scheme_extension_table->scheme_box)
#define scheme_unbox (scheme_extension_table->scheme_unbox)
#define scheme_set_box (scheme_extension_table->scheme_set_box)
#define scheme_make_weak_box (scheme_extension_table->scheme_make_weak_box)
#define scheme_make_late_weak_box (scheme_extension_table->scheme_make_late_weak_box)
#define scheme_make_ephemeron (scheme_extension_table->scheme_make_ephemeron)
#define scheme_ephemeron_value (scheme_extension_table->scheme_ephemeron_value)
#define scheme_ephemeron_key (scheme_extension_table->scheme_ephemeron_key)
#define scheme_make_late_will_executor (scheme_extension_table->scheme_make_late_will_executor)
#define scheme_load (scheme_extension_table->scheme_load)
#define scheme_load_extension (scheme_extension_table->scheme_load_extension)
#define scheme_register_extension_global (scheme_extension_table->scheme_register_extension_global)
#define scheme_get_seconds (scheme_extension_table->scheme_get_seconds)
#define scheme_get_milliseconds (scheme_extension_table->scheme_get_milliseconds)
#define scheme_get_inexact_milliseconds (scheme_extension_table->scheme_get_inexact_milliseconds)
#define scheme_get_process_milliseconds (scheme_extension_table->scheme_get_process_milliseconds)
#define scheme_get_process_children_milliseconds (scheme_extension_table->scheme_get_process_children_milliseconds)
#define scheme_get_thread_milliseconds (scheme_extension_table->scheme_get_thread_milliseconds)
#define scheme_banner (scheme_extension_table->scheme_banner)
#define scheme_version (scheme_extension_table->scheme_version)
#define scheme_check_proc_arity (scheme_extension_table->scheme_check_proc_arity)
#define scheme_check_proc_arity2 (scheme_extension_table->scheme_check_proc_arity2)
#define scheme_make_provided_string (scheme_extension_table->scheme_make_provided_string)
#define scheme_make_args_string (scheme_extension_table->scheme_make_args_string)
#define scheme_make_arg_lines_string (scheme_extension_table->scheme_make_arg_lines_string)
#define scheme_system_library_subpath (scheme_extension_table->scheme_system_library_subpath)
#define scheme_signal_received (scheme_extension_table->scheme_signal_received)
#define scheme_signal_received_at (scheme_extension_table->scheme_signal_received_at)
#define scheme_get_signal_handle (scheme_extension_table->scheme_get_signal_handle)
#define scheme_wait_until_signal_received (scheme_extension_table->scheme_wait_until_signal_received)
#define scheme_char_strlen (scheme_extension_table->scheme_char_strlen)
#define scheme_stx_extract_marks (scheme_extension_table->scheme_stx_extract_marks)
#define scheme_get_place_id (scheme_extension_table->scheme_get_place_id)
#define scheme_get_place_table (scheme_extension_table->scheme_get_place_table)
#define scheme_register_process_global (scheme_extension_table->scheme_register_process_global)
#define scheme_malloc_key (scheme_extension_table->scheme_malloc_key)
#define scheme_free_key (scheme_extension_table->scheme_free_key)
#define scheme_jit_find_code_end (scheme_extension_table->scheme_jit_find_code_end)
#define scheme_jit_now (scheme_extension_table->scheme_jit_now)
#define scheme_set_signal_handler (scheme_extension_table->scheme_set_signal_handler)
#ifdef MZ_PRECISE_GC
#pragma GC_VARIABLE_STACK_THOUGH_TABLE
#endif
